/*==================================================================
 Program: Main_e2010.do
 Purpose: Performs analysis on data from 2010 RCT.
==================================================================*/ 
  
/*==================================================================
PARTS TO THE CODE:
- RANDOMIZATION CHECK
- FIGURES ON BELIEFS
- CORRELATES OF BELIEFS
- FIRST-STAGE: DOES THE CLOSE/NOTCLOSE TREATMENT AFFECT BELIEFS?
- OBSERVATIONAL RELATIONSHIP BETWEEN CLOSENESS AND TURNOUT
- OLS: BELIEFS ABOUT ELECTORAL CLOSENESS AND VOTER TURNOUT
- IV: EFFECTS OF BELIEFS ABOUT ELECTORAL CLOSENESS ON TURNOUT
- VALENCE ANALYSIS: HOW DO POLLS AFFECT PREFERENCES?

The survey time variables in 2010_RCT.dta are for the pre-election
survey.
==================================================================*/

clear
qui do "$Main_P/2010/zz_globals_e2010.do"	
set more off
set matsize 3000

* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T


/*==================================================================
RANDOMIZATION CHECK: We do this two ways:
(1) Among those who did the pre-election beliefs survey.
(2) Among everyone (based on assignment)

The main focus is on (1), reflecting the strong focus
of the paper on understanding closeness beliefs.
==================================================================*/

global Demogs_SS = 		"male black hisp other mixed ppage dropout hs somecoll bachelors mastersphd inc_2550 inc_5075 inc_75100 inc_100p"
global PartyReg_SS = 	"democrat_reg republican_reg npa_dts_indep_reg otherparty_reg"
global PolitVars_SS = 	"pelosi int_govt_scale dem_1to7 liberal_1to7"
global VoteBeliefs_SS = "votemarg_pre prob_100votes_pre prob_1000votes_pre pvote_pre prob_votedem_pre prob_voterep_pre prob_voteunderdog_pre"
global VoteVars_SS = 	"$PastVoteVars vote_admin_past"

global VarNames = 		"$Demogs_SS $PartyReg_SS $PolitVars_SS $VoteBeliefs_SS $VoteVars_SS"

* Number of variables in the summary stats. 
matrix input N = (1\2\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24\25\26\27\28\29\30\31\32\33\34\35\36)

local Vars_In_SS = rowsof(N)

* Close, NotClose, p-value from t-test
matrix input M3 = (1,2,3)

* Close, NotClose, Control, p:1v2, p:1v3, p:2v3
matrix input M6= (1,2,3,4,5,6)

/*================================================
Table C2, Panel A: Provided polls and poll averages
=================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
gen avgrep = 100-avgdem
collapse closedem closerep nclosedem ncloserep avgdem avgrep, by(state_st_assign)
drop if mi(state_st_assign)
foreach yX in closedem closerep nclosedem ncloserep avgdem avgrep{
	gen `yX'_perc=string(`yX')+"\%"
	drop `yX'
	rename `yX'_perc `yX'
}
dataout, save("$ObPath/Tab-PollList-$spec") tex replace

/*================================================
Average poll margins by treatment
=================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
drop if mi(t_close) | mi(state_st_assign)
collapse poll_margin, by(t_close)
sum poll_margin if t_close==1
sum poll_margin if t_close==0



/*================================================
Appendix Table C3: Simple summary statistics
=================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
keep if t_close==0 | t_close==1
sutex $Demogs_SS $PartyReg_SS $PolitVars_SS ///
	votemarg_pre votemarg_post prob_100votes_pre prob_100votes_post /// 
	prob_1000votes_pre prob_1000votes_post pvote_pre pvote_post prob_votedem_pre prob_voterep_pre prob_votedem_post prob_voterep_post ///
	prob_voteunderdog_pre prob_voteunderdog_post vote_sr vote_admin vote_admin_past, /// 
	minmax labels digits(2) 
	
		
/*================================================
Table 1: Comparing mean by treatment
AMONG THOSE WHO DID THE PRE-ELECTION SURVEY.
This is people who were assigned to the Close or NotClose treatments
AND who answered the survey. 
=================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
matrix H=N*M3
matrix colnames H = close notclose pval
matrix rownames H = $Demogs_SS $PartyReg_SS $PolitVars_SS $VoteBeliefs_SS $VoteVars_SS
local Counter = 0
foreach yX of global VarNames{
	local Counter = `Counter'+1
	qui mean `yX', over(t_close)
	matrix J=e(b)
	matrix H[`Counter',1]=J[1,2]
	matrix H[`Counter',2]=J[1,1]	
	qui ttest `yX', by(t_close)
	matrix H[`Counter',3]=round(r(p),.01)	
}
matrix H1 = H
forvalues iX=1/`Vars_In_SS'{
	forvalues kX=1/3{
		matrix H1[`iX',`kX']=round(H[`iX',`kX'],.01)
	}
}
outtable using "$ObPath/Tab-2010Means-CloseNotclose-$spec", mat(H1) nobox replace center

/*================================================
APPENDIX TABLE C5
Comparison among non-responders to the survey.
================================================*/

set more off
use "$Temp/2010_RCT.dta", clear
keep if t_assign_close==1 | t_assign_notclose==1
drop if t_close==0 | t_close==1

matrix input N2 = (1\2\3\4\5\6\7)
local Vars_In_SS2 = rowsof(N2)
matrix H=N2*M3
matrix colnames H = close notclose pval
matrix rownames H = $PartyReg_SS dem_1to7 liberal_1to7 vote_admin_past
global VarNames2 "$PartyReg_SS dem_1to7 liberal_1to7 vote_admin_past"

local Counter = 0
foreach yX of global VarNames2{
	local Counter = `Counter'+1
	qui mean `yX', over(t_assign_close)
	matrix J=e(b)
	matrix H[`Counter',1]=J[1,2]
	matrix H[`Counter',2]=J[1,1]	
	qui ttest `yX', by(t_assign_close)
	matrix H[`Counter',3]=round(r(p),.01)	
}
matrix H1 = H
forvalues iX=1/`Vars_In_SS2'{
	forvalues kX=1/3{
		matrix H1[`iX',`kX']=round(H[`iX',`kX'],.01)
	}
}
outtable using "$ObPath/Tab-2010Means-NonResponders-$spec", mat(H1) nobox replace center

/*================================================
DISCUSSED IN APPENDIX B1
Comparison among all voters in the sample
================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
matrix H=N*M3
matrix colnames H = close notclose control
matrix rownames H = $Demogs_SS $PartyReg_SS $PolitVars_SS $VoteBeliefs_SS $VoteVars_SS
local Counter = 0
foreach yX of global VarNames{
	local Counter = `Counter'+1
	qui mean `yX', over(xpivotal_3groups)
	matrix J=e(b)
	matrix H[`Counter',1]=J[1,1]
	matrix H[`Counter',2]=J[1,2]	
	matrix H[`Counter',3]=J[1,3]	
}
matrix H1 = H
forvalues iX=1/`Vars_In_SS'{
	forvalues kX=1/3{
		matrix H1[`iX',`kX']=round(H[`iX',`kX'],.01)
	}
}
outtable using "$ObPath/Tab-2010Means-3Groups-$spec", mat(H1) nobox replace center

/*================================================
DISCUSSED IN APPENDIX B1
Comparison among all voters in sample, but exclude California.
================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
drop if state_st_assign=="CA"
matrix H=N*M3
matrix colnames H = close notclose control
matrix rownames H = $Demogs_SS $PartyReg_SS $PolitVars_SS $VoteBeliefs_SS $VoteVars_SS
local Counter = 0
foreach yX of global VarNames{
	local Counter = `Counter'+1
	qui mean `yX', over(xpivotal_3groups)
	matrix J=e(b)
	matrix H[`Counter',1]=J[1,1]
	matrix H[`Counter',2]=J[1,2]	
	matrix H[`Counter',3]=J[1,3]	
}
matrix H1 = H
forvalues iX=1/`Vars_In_SS'{
	forvalues kX=1/3{
		matrix H1[`iX',`kX']=round(H[`iX',`kX'],.01)
	}
}
outtable using "$ObPath/Tab-2010Means-3Groups-NoCA-$spec", mat(H1) nobox replace center


* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T

/*==================================================================
FIGURES ON BELIEFS: 
- WHAT IS THE DISTRIBUTION OF VOTER BELIEFS?
- DO BELIEFS OR INTENDED VOTING BEHAVIOR CHANGE AT 
ALL IN RESPONSE TO POLLS?
==================================================================*/


/*================================================
FIGURE 1: DISTRIBUTION OF PRE-TREATMENT BELIEVED 
MARGINS
================================================*/

** Pre-treatment believed vote margin in full population 
** It should always be even.
set more off
use "$Temp/2010_RCT.dta", clear
assert mod(votemarg_pre,2)==0 if ~mi(votemarg_pre)
assert votemarg_pre>=0 &  votemarg_pre<=100 if ~mi(votemarg_pre)
sum votemarg_pre, detail
global Median = r(p50)
global P25 = r(p25)
global P75 = r(p75)
histogram votemarg_pre if votemarg_pre>=0, discrete width(1) start(0) xlabel(0(10)100) xmtick(0(5)100) ///
	ylabel(0(.05).2) xtitle(Predicted vote margin) ///
	note("Median = $Median, 25th Percentile = $P25, 75th Percentile = $P75") ///
	graphr(fc(white)) 
graph export "$ObPath/Figures/Fig-PredMarginPre.pdf", as(pdf) replace


/*================================================
FIGURE 2: DISTRIBUTION OF BELIEFS
Subjective Probabilities that Gubernatorial Election Will be Decided by Less
than 100 Votes or 1,000 Votes, Before Treatment
================================================*/

** Figure 2: Initial graphs using full population 
set more off
use "$Temp/2010_RCT.dta", clear
foreach iX in 100 1000{ 
assert prob_`iX'votes_pre>=0 & prob_`iX'votes_pre<=100 if ~mi(prob_`iX'votes_pre)
sum prob_`iX'votes_pre, detail
global Median = r(p50)
global P25 = r(p25)
global P75 = r(p75)
histogram prob_`iX'votes_pre , discrete width(1) start(0) xlabel(0(10)100) xmtick(0(5)100) ///
	ylabel(0(.05).2) xtitle(Prob margin < `iX' votes) ///
	note("Median = $Median, 25th Percentile = $P25, 75th Percentile = $P75") ///
	graphr(fc(white)) 
graph export "$ObPath/Figures/Fig-Prob`iX'VotesPre.pdf", as(pdf) replace
}

** Appendix Figure C2: Restrict to Master's or PhD
set more off
use "$Temp/2010_RCT.dta", clear
keep if mastersphd==1
foreach iX in 100 1000{ 
assert prob_`iX'votes_pre>=0 & prob_`iX'votes_pre<=100 if ~mi(prob_`iX'votes_pre)
sum prob_`iX'votes_pre, detail
global Median = r(p50)
global P25 = r(p25)
global P75 = r(p75)
histogram prob_`iX'votes_pre, discrete width(1) start(0) xlabel(0(10)100) xmtick(0(5)100) ///
	ylabel(0(.05).2) xtitle(Prob margin < `iX' votes) ///
	note("Median = $Median, 25th Percentile = $P25, 75th Percentile = $P75") ///
	graphr(fc(white)) 
graph export "$ObPath/Figures/Fig-Prob`iX'VotesPre-MasterPHD.pdf", as(pdf) replace
}


/*================================================
IMPACT OF POLLS ON DISTRIBUTION OF BELIEFS:
Appendix Figure C3: Distribution of Beliefs 
About a Very Close Election Before and After 
the Close and Not Close Treatments
================================================*/
foreach kX in votemarg prob_100votes prob_1000votes {
use "$Temp/2010_RCT.dta", clear
keep if t_close==0 | t_close==1
gen insamp = ~mi(`kX'_pre) & ~mi(`kX'_post)
keep if insamp==1
foreach yX in 0 1 {
twoway (histogram `kX'_pre if t_close==`yX', discrete width(1) start(0) xlabel(0(10)100) xmtick(0(5)100) color(green)  ) ///
       (histogram `kX'_post if t_close==`yX', discrete width(1) start(0) xlabel(0(10)100) xmtick(0(5)100) fcolor(none) lcolor(black)) , ///
	   legend( label(1 "Pre-Treat") label(2 "Post-Treat") ) ///
	   ytitle("Density") ///
	   graphregion(fcolor(white) lcolor(white))
graph export "$ObPath/Figures/Fig-DistPrePost-`kX'-tclose`yX'.pdf", as(pdf) replace
}		
}


* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T


/*================================================
FIGURE 4: DEGREE OF BELIEF UPDATING IN RESPONSE 
TO POLLS.
================================================*/

** Figure 4a: Include all subjects.
set more off
use "$Temp/2010_RCT.dta", clear
gen index = .
gen coefficient =.
gen utail =.
gen ltail =.
local i 1
foreach yX in votemarg prob_100votes prob_1000votes {
	reg `yX'_change if t_close==1, robust
	replace utail = _b[_cons] + invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace ltail = _b[_cons] - invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace coefficient = _b[_cons] if _n== `i'
	replace index = `i' if _n ==`i'
	local ++i
	reg `yX'_change if t_close==0, robust
	
	replace utail = _b[_cons] + invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace ltail = _b[_cons] - invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace coefficient = _b[_cons] if _n== `i'
	replace index = `i' if _n == `i'
	local ++i
}
graph twoway (bar coefficient index if index==1|index==3|index==5) ///
	(bar coefficient index if index==2|index==4|index==6) ///
	(rcap utail ltail index, lcolor(black) blwidth(medthick) msize(large)), scheme(sj) ///
	xscale(off) ytitle(Change in Probability) graphr(fc(white)) legend(order(1 2) ///
	label(1 "Close") label(2 "Not Close")) text(-0.5 1.5 "Vote Margin") ///
	text(-0.5 3.5 "Less than 100 votes") text(-0.5 5.5 "Less than 1,000 votes")
graph export "$ObPath/Figures/Fig-UpdateBeliefs.pdf", as(pdf) replace


** Figure 4b: Restrict to subjects who change beliefs.
set more off
use "$Temp/2010_RCT.dta", clear
gen index = .
gen coefficient =.
gen utail =.
gen ltail =.
local i 1
foreach yX in votemarg prob_100votes prob_1000votes {
	reg `yX'_change if t_close==1 & `yX'_change!=0, robust
	replace utail = _b[_cons] + invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace ltail = _b[_cons] - invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace coefficient = _b[_cons] if _n== `i'
	replace index = `i' if _n ==`i'
	local ++i
	reg `yX'_change if t_close==0 & `yX'_change!=0, robust
	
	replace utail = _b[_cons] + invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace ltail = _b[_cons] - invttail(e(df_r),0.025)*_se[_cons] if _n== `i'
	replace coefficient = _b[_cons] if _n== `i'
	replace index = `i' if _n == `i'
	local ++i
}
graph twoway (bar coefficient index if index==1|index==3|index==5) ///
	(bar coefficient index if index==2|index==4|index==6) ///
	(rcap utail ltail index, lcolor(black) blwidth(medthick) msize(large)), scheme(sj) ///
	xscale(off) ytitle(Change in Probability) graphr(fc(white)) legend(order(1 2) ///
	label(1 "Close") label(2 "Not Close")) text(-0.5 1.5 "Vote Margin") ///
	text(-0.5 3.5 "Less than 100 votes") text(-0.5 5.5 "Less than 1,000 votes")
graph export "$ObPath/Figures/Fig-UpdateBeliefs-Changers.pdf", as(pdf) replace



/*==================================================================
Appendix Table C6: CORRELATES OF BELIEFS
The global "BeliefControls" is defined in "zz_globals_e2010.do".
==================================================================*/	
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
use "$Temp/2010_RCT.dta", clear
reg `kX'_pre $BeliefControls, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123))
	outreg2 using "$ObPath/Tab-DetermineBeliefs-$spec", $OR2 append 
areg `kX'_pre $BeliefControls, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123)) absorb(ppstaten)
	outreg2 using "$ObPath/Tab-DetermineBeliefs-$spec", $OR2 append
}

	
/*==============================================================
FIRST-STAGE: DOES THE CLOSE/NOTCLOSE TREATMENT AFFECT BELIEFS?
==============================================================*/

* Useful for Doing Outregging		
winexec taskkill /F /IM Notepad.exe /T

/*================================================
NON-PARAMETRIC IMPACTS ON BELIEFS (Figure 3 in Main Text)
=================================================*/
set more off
use "$Temp/2010_RCT.dta", clear
label define t_close_lbl 0 `"Not close"'
label define t_close_lbl 1 `"Close"', add
label values t_close t_close_lbl
foreach yX in votemarg prob_100votes prob_1000votes pvote prob_voteunderdog {
capture drop order
gen order = .
replace order=1 if `yX'_change_sign=="Decrease"
replace order=2 if `yX'_change_sign=="Same"
replace order=3 if `yX'_change_sign=="Increase"
catplot t_close `yX'_change_sign, percent(t_close) var2opts(sort(order) label(labsize(vlarge))) ///
	asyvars bar(1, color(gs12)) bar(2, color(gs8)) scheme(s1color) aspect(1) ///
	blabel(total, format(%8.1f) size(large))  yscale(range(0 100) noextend) ///
	ylabel(0(20)100, nogrid) ytitle("") legend(size(vlarge))	
graph export "$ObPath/Fig-IncDecSame-`yX'.pdf", as(pdf) replace
}


/*================================================
BASELINE RESULTS ON VOTE MARGIN (Table 2 in Main Text)
zX = Sample restriction
	~ foreach zX in all {
kX = Treatment variable analyzed	
	~ foreach kX in t_close poll_margin {
Table 2 = Discrete Version with "t_close"
Table C7 = Continuous Version with "poll_margin"	
=================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach zX in all {
foreach kX in t_close poll_margin {
use "$Temp/2010_RCT.dta", clear
keep if `zX'==1
reg votemarg_post `kX', robust 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) replace
areg votemarg_post `kX' $demogs, robust absorb(ppstaten) 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg votemarg_post votemarg_pre `kX' $demogs, robust absorb(ppstaten) 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 votemarg_pre `kX' using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2 addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg votemarg_change `kX' $demogs, robust absorb(ppstaten) 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_change) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(votemarg_change) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)	
	outreg2 `kX' using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg votemarg_post `kX' $Polit_Controls $demogs, robust absorb(ppstaten) 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)	
	outreg2 `kX' $Polit_Controls using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg votemarg_post `kX' `kX'Xint_govt_scale $Polit_Controls $demogs, robust absorb(ppstaten)
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 votemarg_post `kX' `kX'Xint_govt_scale $Polit_Controls using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg votemarg_post `kX' `kX'Xpelosi $Polit_Controls $demogs, robust absorb(ppstaten)
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)	
	outreg2 `kX' `kX'Xpelosi $Polit_Controls using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg votemarg_post `kX' `kX'Xvote_admin_past $Polit_Controls $demogs, robust absorb(ppstaten)
	capture drop zz zz1 yy yy1
	egen zz1 = mean(votemarg_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)
	egen yy1 = median(votemarg_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' `kX'Xvote_admin_past $Polit_Controls using "$ObPath/Tab-TreatBeliefs-`kX'-`zX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
}
}


/*================================================
TABLE 3: IMPACT ON PERCEIVED LIKELIHOOD OF ELECTION
BEING DECIDED BY LESS THAN X VOTES.
Table 3 = Discrete Version with "t_close"
Table C8 = Continuous Version with "poll_margin"
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach kX in t_close poll_margin {
use "$Temp/2010_RCT.dta", clear
foreach yX in prob_100votes prob_1000votes prob_xvotes {
reg `yX'_post `kX', robust
	capture drop zz zz1 yy yy1
	egen zz1 = mean(`yX'_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(`yX'_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' using "$ObPath/Tab-TreatBeliefs-XVotes-`kX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
reg `yX'_post `kX' `yX'_pre, robust
	capture drop zz zz1 yy yy1
	egen zz1 = mean(`yX'_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(`yX'_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' `yX'_pre using "$ObPath/Tab-TreatBeliefs-XVotes-`kX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg `yX'_post `kX' `yX'_pre $demogs, robust absorb(ppstaten) 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(`yX'_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(`yX'_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' `yX'_pre using "$ObPath/Tab-TreatBeliefs-XVotes-`kX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
}
}

/*================================================
Table C9: Same as Table 3, but Restrict to Cases 
Where People Change Beliefs.
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach kX in t_close {
use "$Temp/2010_RCT.dta", clear
foreach yX in votemarg prob_100votes prob_1000votes prob_xvotes {
reg `yX'_post `kX' if `yX'_change!=0, robust
	capture drop zz zz1 yy yy1
	egen zz1 = mean(`yX'_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(`yX'_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' using "$ObPath/Tab-TreatBeliefs-Change-`kX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
reg `yX'_post `kX' `yX'_pre if `yX'_change!=0, robust
	capture drop zz zz1 yy yy1
	egen zz1 = mean(`yX'_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(`yX'_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' `yX'_pre using "$ObPath/Tab-TreatBeliefs-Change-`kX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
areg `yX'_post `kX' `yX'_pre $demogs if `yX'_change!=0, robust absorb(ppstaten) 
	capture drop zz zz1 yy yy1
	egen zz1 = mean(`yX'_post) if e(sample)==1 & `kX'==0
	egen zz = max(zz1)	
	egen yy1 = median(`yX'_post) if e(sample)==1 & `kX'==0
	egen yy = max(yy1)
	outreg2 `kX' `yX'_pre using "$ObPath/Tab-TreatBeliefs-Change-`kX'-$spec", $OR2_addtext addstat(Mean DV if `kX'=0, zz, Median DV if `kX'=0, yy) append
}
}


/*==================================================================
OBSERVATIONAL RELATIONSHIP BETWEEN CLOSENESS AND TURNOUT
==================================================================*/

/*================================================
Appendix Table C11 with SE clustered by state
=================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
keep if t_close==0 | t_close==1
sort ppstaten
by ppstaten: gen st_count = _N
collapse vote_admin1 vote_admin_past margin_actual st_count, by(ppstaten)
reg vote_admin1 margin_actual, cluster(ppstaten)
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2 replace
reg vote_admin1 margin_actual vote_admin_past, cluster(ppstaten)
	outreg2 margin_actual vote_admin_past using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2 append


/*================================================
Appendix Table C11 with wild bootstrap
=================================================*/	
* Column 1
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
keep if t_close==0 | t_close==1
sort ppstaten
by ppstaten: gen st_count = _N
collapse vote_admin1 vote_admin_past margin_actual st_count, by(ppstaten)
global Col_1_regressors "margin_actual"
global Col_1_reg "reg vote_admin1 $Col_1_regressors, cluster(ppstaten)"
	$Col_1_reg
	bootwildct $Col_1_regressors, bootreps($BReps) numvars(1) seed(123)
	scalar zz = trace(e(t_wild_pval))
$Col_1_reg
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2_addtext addstat(wild p value,zz) replace

* Column 2	
global Col_2_regressors "margin_actual vote_admin_past"
global Col_2_reg "reg vote_admin1 $Col_2_regressors, cluster(ppstaten)"
	$Col_2_reg
	bootwildct $Col_2_regressors, bootreps($BReps) numvars(1) seed(123)
	scalar zz = trace(e(t_wild_pval))
$Col_2_reg
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2_addtext addstat(wild p value,zz) append	
		
* Column 3
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
global Col_3_regressors "margin_actual"
global Col_3_reg "reg vote_admin1 $Col_3_regressors, cluster(ppstaten)"
	$Col_3_reg
	bootwildct $Col_3_regressors, bootreps($BReps) numvars(1) seed(123)
	scalar zz = trace(e(t_wild_pval))
$Col_3_reg
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2_addtext addstat(wild p value,zz) append

* Column 4
global Col_4_regressors "margin_actual $demogs"
global Col_4_reg "reg vote_admin1 $Col_4_regressors, cluster(ppstaten)"
	$Col_4_reg
	bootwildct $Col_4_regressors, bootreps($BReps) numvars(1) seed(123)
	scalar zz = trace(e(t_wild_pval))
$Col_4_reg
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2_addtext addstat(wild p value,zz) append

* Column 5	
global Col_5_regressors "margin_actual $PastVoteVars $demogs"
global Col_5_reg "reg vote_admin1 $Col_5_regressors, cluster(ppstaten)"
	$Col_5_reg
	bootwildct $Col_5_regressors, bootreps($BReps) numvars(1) seed(123)
	scalar zz = trace(e(t_wild_pval))
$Col_5_reg
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-$spec", $OR2_addtext addstat(wild p value,zz) append		
	

/*================================================
Appendix Table C11 with block bootstrap
=================================================*/		
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
keep if t_close==0 | t_close==1
sort ppstaten
by ppstaten: gen st_count = _N
collapse vote_admin1 vote_admin_past margin_actual st_count, by(ppstaten)
reg vote_admin1 margin_actual, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123))
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-BBStrap-$spec", $OR2 replace
reg vote_admin1 margin_actual vote_admin_past, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123))
	outreg2 margin_actual vote_admin_past using "$ObPath/Table-VoteOLSAdmin-LitReg-BBStrap-$spec", $OR2 append	
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear	
reg vote_admin1 margin_actual, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123))
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-BBStrap-$spec", $OR2 append	
reg vote_admin1 margin_actual $demogs, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123))	
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-BBStrap-$spec", $OR2 append		
reg vote_admin1 margin_actual $demogs $PastVoteVars, vce(bootstrap, cluster(ppstaten) reps($BBReps) seed(123))	
	outreg2 margin_actual using "$ObPath/Table-VoteOLSAdmin-LitReg-BBStrap-$spec", $OR2 append			


/*==================================================================
OLS: BELIEFS ABOUT ELECTORAL CLOSENESS AND VOTER TURNOUT
==================================================================*/
		
/*================================================
TABLE C10: OLS Relation of Beliefs and Turnout

We show the results three main ways:
(1) Base: state FEs and Past Voting controls.
(2) Add pre-treatment beliefs.
(3) Add Demogs.

kX = Regressor being analyzed	
	~ foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
=================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
xi: reg vote_admin1 `kX'_post $BaseVars_V2010, robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post using "$ObPath/Table-VoteOLSAdmin-$spec", $OR2_addtext addstat(Mean DV, zz) append
xi: reg vote_admin1 `kX'_post `kX'_pre $BaseVars_V2010, robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteOLSAdmin-$spec", $OR2_addtext addstat(Mean DV, zz) append
xi: reg vote_admin1 `kX'_post `kX'_pre $FullCont_V2010, robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteOLSAdmin-$spec", $OR2_addtext addstat(Mean DV, zz) append
}


/*================================================
Table C12: DEMOGRAPHICS AND TURNOUT.
=================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
areg vote_admin1 votemarg_post $demogs, absorb(ppstaten) robust
	outreg2 using "$ObPath/Table-VoteAdminOLS-Demogs", $OR2 bdec(3) replace
areg vote_admin1 votemarg_post $demogs $PastVoteVars, absorb(ppstaten) robust
	outreg2 using "$ObPath/Table-VoteAdminOLS-Demogs", $OR2 bdec(3) append
	
	
/*==================================================================
IV: EFFECTS OF BELIEFS ABOUT ELECTORAL CLOSENESS ON TURNOUT
==================================================================*/

/*================================================
We show the results three main ways:
(1) Base: state FEs and Past Voting controls.
(2) Add pre-treatment beliefs.
(3) Add Demogs.

~ TABLE 4: Baseline results. Use "all".
~ Table C19: Exclude people who always voted previously in data. Use "~vote_always".
~ FN 43: Exclude people who always voted or never voted. Use "vote_onlysome".
~ Table C27: Use people who don't change prob of voting D. Use "prob_votedem_change==0".
~ FN 45: Restrict to people with low interest in govt. Use "int_govt_01==0".
~ Table C24: Restrict to people with high interest in govt. Use "int_govt_01".
~ FN 45: Use people with middle political ideology. Use "ideology_middle".
~ Table C23: Restrict to people with strong ideology. Use "ideology_partisan".
~ Table C25: Restrict to people in states with smaller electorates. Use "small_state".
~ Not used: Restrict to people with active voter status. Use "vs_active".
~ Table C18. Use half of sample taking survey closest to election. Use "half_closest_to_election".
~ Discussed in-text in Section 4A: restrict to states where we use 
	a 50/50 close poll. Use "state_close50".

One needs to loop through all the below options to produce the different tables.	
	
yX = Sample restriction or subsample	
	~ foreach yX in all ~vote_always vote_onlysome ~vote_never prob_votedem_change==0 int_govt_01==0 int_govt_01 ideology_middle ideology_partisan small_state vs_active half_closest_to_election state_close50{
kX = Regressor being analyzed	
	~ foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach yX in all {
use "$Temp/2010_RCT.dta", clear
keep if `yX'==1
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
xi: ivreg2 vote_admin1 (`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post using "$ObPath/Table-VoteIVAdmin-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-FS-`yX'-$spec", $OR2 append		
}
}

	
/*================================================
Mentioned at End of Appendix A2: Log beliefs.
Also mentioned at bottom of Table C22.
yX = Sample restriction or subsample	
	~ foreach yX in all{
kX = Regressor being analyzed	
	~ foreach kX in votemarg prob_100votes {
	~ foreach kX in prob_1000votes {
	~ foreach kX in prob_xvotes {
================================================*/		
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach yX in all{
use "$Temp/2010_RCT.dta", clear
keep if `yX'==1	
foreach kX in votemarg prob_100votes {
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append		
}
foreach kX in prob_1000votes {
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_pos
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_pos
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_pos
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append		
}
foreach kX in prob_xvotes {
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdmin-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-Log-FS-`yX'-$spec", $OR2 append		
}
}	
	
/*================================================
Appendix Table C22: Log beliefs and Restrict to People 
who Update Beliefs

yX = Sample restriction or subsample	
	~ foreach yX in all{
kX = Regressor being analyzed	
	~ foreach kX in votemarg prob_100votes {
	~ foreach kX in prob_1000votes {
	~ foreach kX in prob_xvotes {
================================================*/		
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach yX in all{
foreach kX in votemarg prob_100votes {
use "$Temp/2010_RCT.dta", clear
keep if `yX'==1	
keep if `kX'_change!=0
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append		
}
foreach kX in prob_1000votes {
use "$Temp/2010_RCT.dta", clear
keep if `kX'_change!=0
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_pos
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_pos
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_pos
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append		
}
foreach kX in prob_xvotes {
use "$Temp/2010_RCT.dta", clear
keep if `kX'_change!=0
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) $BaseVars_V2010, first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $BaseVars_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (l`kX'_post=t_close) l`kX'_pre $FullCont_V2010,  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 l`kX'_post l`kX'_pre using "$ObPath/Table-VoteIVAdminCB-Log-`yX'-$spec", $OR2_fstatmdv append
	est restore _ivreg2_l`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdminCB-Log-FS-`yX'-$spec", $OR2 append		
}
}			
		
		
/*================================================
Table C21: Restrict to people who update their beliefs.
kX = Regressor being analyzed	
	~ foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
================================================*/			
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
use "$Temp/2010_RCT.dta", clear
keep if `kX'_change!=0
xi: ivreg2 vote_admin1 (`kX'_post=t_close) $BaseVars_V2010,  first robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post using "$ObPath/Table-VoteIVAdmin-ChangeBeliefs-$spec", $OR2_fstatmdv append
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $BaseVars_V2010,  first robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-ChangeBeliefs-$spec", $OR2_fstatmdv append	
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $FullCont_V2010,  first robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-ChangeBeliefs-$spec", $OR2_fstatmdv append
}	
	

/*================================================
Table C13: Don't control for past voting history.
kX = Regressor being analyzed
	~ foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
xi: ivreg2 vote_admin1 (`kX'_post=t_close) $BaseVars_V2010_NoPastV,  first robust 
	outreg2 `kX'_post using "$ObPath/Table-VoteIVAdmin-NoPastVoting-$spec", $OR2_fstat append
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $BaseVars_V2010_NoPastV,  first robust 
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-NoPastVoting-$spec", $OR2_fstat append	
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $FullCont_V2010_NoPastV,  first robust 
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-NoPastVoting-$spec", $OR2_fstat append
}

/*================================================
Table C17: Weight by day of survey
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
xi: ivreg2 vote_admin1 (`kX'_post=t_close) $BaseVars_V2010 [aw=day_survey], first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post using "$ObPath/Table-VoteIVAdmin-AWDayOfSurvey-$spec", $OR2_fstatmdv append
	est restore _ivreg2_`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-FS-AWDayOfSurvey-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $BaseVars_V2010 [aw=day_survey],  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-AWDayOfSurvey-$spec", $OR2_fstatmdv append
	est restore _ivreg2_`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-FS-AWDayOfSurvey-$spec", $OR2 append	
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $FullCont_V2010 [aw=day_survey],  first savefirst robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIVAdmin-AWDayOfSurvey-$spec", $OR2_fstatmdv append
	est restore _ivreg2_`kX'_post
	outreg2 t_close using "$ObPath/Table-VoteIVAdmin-FS-AWDayOfSurvey-$spec", $OR2 append		
}


/*================================================
OTHER OUTCOME VARIABLES BESIDES ADMIN TURNOUT.

~ TABLE 5: IMMEDIATE INTENTION OF VOTING AFTER TREATMENT.
Intention to vote="pvote_post" is on a scale from 0 to 100.

~ Table C16: Information Acquisition.
For information acquisition, we asked people whether they started 
to pay more or less attention to the campaigns after taking our 
pre-election survey. 
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
assert pvote_post>=0 & pvote_post<=100 if ~mi(pvote_post)
foreach yX in pvote_post attention_change1 {
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
xi: ivreg2 `yX' (`kX'_post=t_close) $BaseVars_V2010,  first robust 
	capture drop zz zz1
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post using "$ObPath/Table-VoteIV`yX'-$spec", $OR2_fstatmdv append
xi: ivreg2 `yX' (`kX'_post=t_close) `kX'_pre $BaseVars_V2010,  first robust 
	capture drop zz zz1
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIV`yX'-$spec", $OR2_fstatmdv append	
xi: ivreg2 `yX' (`kX'_post=t_close) `kX'_pre $FullCont_V2010,  first robust 
	capture drop zz zz1
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = max(zz1)
	outreg2 `kX'_post `kX'_pre using "$ObPath/Table-VoteIV`yX'-$spec", $OR2_fstatmdv append
}	
}	

* In Section 2C, asides on correlation between intended prob of voting 
* and administrative voting, and on means.
set more off
use "$Temp/2010_RCT.dta", clear
pwcorr pvote_post vote_admin
assert round(r(rho),.01)==0.46
sum pvote_post if t_close==1
sum pvote_post if t_close==0

		
/*================================================
Calculate simple summary stats on how long it took
people to answer the vote margins and very close 
election prob questions, as well as the amount of 
time spent looking at the polls. 
================================================*/			

* In Section 4A, we point out that people took significant
* time to answer the beliefs questions.
* These are also referenced in Appendix A.3.
set more off
use "$Temp/2010_RCT.dta", clear
sum time_votemarg_pre, detail
assert r(p50)==35 & r(p10)==19 & r(p90)==78
sum time_prob_xvotes_pre, detail
assert r(p50)==16 & r(p10)==9 & r(p90)==36

* Time spent looking at main screen with the polls.
* This is discussed in FN 26.
use "$Temp/2010_RCT.dta", clear
sum time_on_poll, detail
assert round(r(p50))==16
gen time_on_poll_overmin = (time_on_poll>60) if ~mi(time_on_poll)
sum time_on_poll_overmin
assert round(r(mean),.01)==.03

		
/*==================================================================
Table C29: 2010 REDUCED FORM ANALYSIS.
==================================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear
xi: reg vote_admin1 t_close $BaseVars_V2010, robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1 & t_close==0
	egen zz = max(zz1)	
	outreg2 t_close using "$ObPath/Table-VoteAdmin-RedForm-$spec", $OR2_addtext addstat(Mean DV if not close poll=1, zz) replace
xi: reg vote_admin1 t_close $FullCont_V2010, robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1 & t_close==0
	egen zz = max(zz1)
	outreg2 t_close using "$ObPath/Table-VoteAdmin-RedForm-$spec", $OR2_addtext addstat(Mean DV if not close poll=1, zz) append
* We control for "state" instead of "ppstaten" because "ppstaten" is missing
* for people who did not take the survey.
xi: reg vote_admin1 t_assign_close t_assign_notclose i.state $PastVoteVars, robust 
	capture drop zz zz1
	egen zz1 = mean(vote_admin1) if e(sample)==1 & t_assign_control==1
	egen zz = max(zz1)	
	outreg2 t_assign_close t_assign_notclose using "$ObPath/Table-VoteAdmin-RedForm-$spec", $OR2_addtext addstat(Mean DV if assigned to control=1, zz) append	
	

/*================================================================== 
VALENCE ANALYSIS: HOW DO POLLS AFFECT PREFERENCES?
- How does seeing that the Democrat is more-favored affect whether 
people vote Democrat (self-reported in post-election survey) or
the intended prob of voting Democrat in pre-election survey?
==================================================================*/ 

/*================================================
FN 42: "The correlation between post-treatment predicted 
Dem vote share and actual Dem vote share is 0.42."
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"	
use "$Temp/2010_RCT.dta", clear
pwcorr demshare_post demshare
assert round(r(rho),.01)==0.42

/*================================================
Table C31: Actual Voting for the Democrat (based on 
post-selection survey)
================================================*/
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"	
use "$Temp/2010_RCT.dta", clear
reg demshare_post poll_dem $BaseDemVars, robust
	outreg2 poll_dem using "$ObPath/Table-VoteDem-$spec", $OR2_fstat replace
xi: reg vote_govdem1 demshare_post $BaseDemVars, robust
	outreg2 demshare_post using "$ObPath/Table-VoteDem-$spec", $OR2_fstat append
gen insamp = e(sample)==1
reg demshare_post poll_dem $BaseDemVars if insamp==1, robust
xi: ivreg2 vote_govdem1 (demshare_post= poll_dem) $BaseDemVars,  first robust
	outreg2 demshare_post using "$ObPath/Table-VoteDem-$spec", $OR2_fstat append
xi: ivreg2 vote_govdem1 (demshare_post= poll_dem)  demshare_pre $BaseDemVars,  first robust
	outreg2 demshare_post demshare_pre using "$ObPath/Table-VoteDem-$spec", $OR2_fstat append	
xi: ivreg2 vote_govdem1 (demshare_post= poll_dem)  demshare_pre $FullDemCont,  first robust
	outreg2 demshare_post demshare_pre using "$ObPath/Table-VoteDem-$spec", $OR2_fstat append	
	
		
/*================================================
Table C32: Intend Prob of Voting for Democrat
================================================*/	
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"	
use "$Temp/2010_RCT.dta", clear
xi: reg prob_votedem_post demshare_post $BaseDemVars, robust
	outreg2 demshare_post using "$ObPath/Table-VoteDemIntent-$spec", $OR2_fstat replace
xi: ivreg2 prob_votedem_post (demshare_post= poll_dem) $BaseDemVars,  first robust
	outreg2 demshare_post using "$ObPath/Table-VoteDemIntent-$spec", $OR2_fstat append
xi: ivreg2 prob_votedem_post (demshare_post= poll_dem)  demshare_pre $BaseDemVars,  first robust
	outreg2 demshare_post demshare_pre using "$ObPath/Table-VoteDemIntent-$spec", $OR2_fstat append	
xi: ivreg2 prob_votedem_post (demshare_post= poll_dem)  demshare_pre $FullDemCont,  first robust
	outreg2 demshare_post demshare_pre using "$ObPath/Table-VoteDemIntent-$spec", $OR2_fstat append	
	
		



