/*==================================================================
 Program: CPS_Clean
 Purpose: Cleaning CPS Voter Supplement data 
==================================================================*/ 

use "$Temp/CPS_raw.dta", clear

* To remove all individuals 'not in universe' (i.e. people not registered to vote), run
keep if (voted == 02 | (voted!= 02 & voreg == 02))
* Note that the CPS assumes that individuals that voted during the most recent November elections were already registered. 
* Thus, the universe for voreg comprises only persons who did not vote.
* Note also that some remaining variables may still appear as 'Not in universe', but this 
* seems to be due the fact that, in the original data, blanks and Not in Universes 
* were given the same code.

* To define new dummy variables as in the paper, run
generate male = 1 if sex == 1 
replace male = 0 if sex == 2
label var male 	`"Male"'

generate black = 1 if (race == 200 & hispan == 000)
replace black = 0 if (race !=200 | hispan !=000)
label var black `"Black"'

generate hisp = 1 if hispan !=000 
replace hisp = 0 if hispan == 000
label var hisp `"Hispanic"'

generate other = 1 if ((race>=300 & race<=700) & hispan == 000)
replace other = 0 if (race<300 | race>700 | hispan != 000) 
label var other `"Other (not White, Black, Hispanic, or Mixed)"'

generate mixed = 1 if (race>=801 & race <=830 & hispan == 000)
replace mixed = 0 if (race < 801 | hispan != 000)
label var mixed `"Mixed race (and not Hispanic)

generate dropout = 1 if (educ >=002 & educ <= 032) 
replace dropout = 0  if (educ>032 & educ!=999)
label var dropout `"Less than high school"'

generate hs = 1 if educ ==073
replace hs = 0 if (educ !=073 & educ!=000 & educ!=001 & educ!=999)
label var hs `"High school degree"'

generate somecoll = 1 if (educ >=80 & educ <=110 | educ == 120 | educ == 121 | educ == 122)
replace somecoll = 0 if ((educ <80 | educ == 111 | educ > 122)  & educ!=000 & educ!=001 & educ!=999)
label var somecoll `"Some college or associate degree"'

generate bachelors = 1 if educ == 111
replace bachelors = 0 if (educ !=111 & educ!=000 & educ!=001 & educ!=999)
label var bachelors `"Bachelor's degree"'

generate mastersphd = 1 if (educ>=123 & educ <=125)
replace mastersphd = 0 if ((educ <123 | educ >125)  & educ!=000 & educ!=001 & educ!=999)
label var mastersphd `"Master's or PhD"'

generate inc_2550 = 1 if (faminc>=700 & faminc <=740)
replace inc_2550 = 0 if ((faminc<700 | faminc >740) & faminc<995)
label var inc_2550 `"Household income 25k-50k"'

generate inc_5075 = 1 if (faminc >=810 & faminc <= 830)
replace inc_5075 = 0 if ((faminc < 810 | faminc > 830) & faminc<995)
label var inc_5075 `"Household income 50k-75k"'

generate inc_75100 = 1 if faminc == 841
replace inc_75100 = 0 if (faminc != 841 & faminc<995)
label var inc_75100 `"Household income 75k-100k"'

generate inc_100p = 1 if (faminc == 842 | faminc == 843)
replace inc_100p = 0 if ((faminc <842 | faminc > 843) & faminc<995)
label var inc_100p `"Household income 100k +"'

generate vote_sr = 1 if voted == 02
replace vote_sr = 0 if voted != 02
label var vote_sr `"Voted (self-reported)"'

generate state_2010 = 1 if (statefip == 06 | statefip == 09 | statefip == 12 | statefip == 13 | statefip == 17 | statefip == 24 | statefip == 33 | statefip == 36  | statefip == 39 | statefip == 41 | statefip == 42  | statefip == 48 | statefip == 55)
label var state_2010 `"State in 2010 sample"'

generate state_2014 = 1 if (statefip ==  05 | statefip == 12 | statefip == 13 | statefip == 20 | statefip == 25 | statefip == 26 | statefip == 55)
label var state_2014 `"State in 2014 sample"'

save "$Temp/CPS.dta", replace


/*==================================================================
Add an ID to datasets
==================================================================*/ 
foreach yX in 2010 2014{
	use "$Temp/`yX'_RCT.dta", clear
	gen rct_`yX' = 1
	label variable rct_`yX' "Equals 1 for rct_`yX'"
	save "$Temp/`yX'_RCT_V2.dta", replace
}


/*==================================================================
Append the datasets together.
==================================================================*/ 

use "$Temp/CPS.dta", clear

append using "$Temp/2010_RCT_V2.dta"
append using "$Temp/2014_RCT_V2.dta", force

foreach yX in 2010 2014{
	replace rct_`yX'=0 if mi(rct_`yX')
}

assert mi(year) if rct_2010==1 | rct_2014==1
gen cps = 1 if (year == 2010 | year == 2014)
replace cps = 0 if mi(cps)
label variable cps "Equals 1 for CPS"
assert rct_2010 + rct_2014 + cps==1

* Little data cleaning with newly appended dataset
replace age = ppage if rct_2010 == 1
replace other = race_other if rct_2014 == 1

*cf _all using "$Temp/CPS_Combo.dta"
save "$Temp/CPS_Combo.dta", replace
