/*==================================================================
 Program: Combo_Tables.do
 Purpose: Analysis combining the 2010 and 2014 RCTs.
==================================================================*/

/*==================================================================
PARTS TO THE CODE:
1. COMBINE THE 2014 AND 2010 DATA.
2. USING 2014 DATA: DO TSIV AND ESTIMATE "s".
3. USING COMBINED DATA: DO TSIV AND ESTIMATE "s".
4. USING 2010 DATA: REPEAT MAIN IV RESULTS AND ESTIMATE "s".
5. MISCELLANEOUS ANALYSES
==================================================================*/

clear
set more off
winexec taskkill /F /IM Notepad.exe /T

* Assumed observational relationship between closeness and turnout
scalar B_ClosenessTurnout = .34

* Assumed share of impact on beliefs for 2014 RCT relative to 
* size of impact in 2010 RCT. Our base spec assumes Theta=1. 
scalar Theta = 1

* Correlation coefficients. Discussed in Web Appendix FN 12.
scalar Rho12 = 0.5
scalar Rho13 = 0.5
scalar Rho23 = 0.5


/*==================================================================
1. COMBINE THE 2014 AND 2010 DATA.
==================================================================*/
set more off
use "$Temp/2014_RCT.dta", clear
gen year = 2014
* Get rid of observations in control group from 2014.
drop if mi(t_close)
append using "$Temp/2010_RCT.dta"
replace year = 2010 if mi(year)
* Get rid of individuals not getting the poll from 2010.
drop if mi(t_close)
save "$Temp/BothYears.dta", replace



/*==================================================================
2. USING 2014 DATA: DO TSIV AND ESTIMATE "s".

Steps:
- Get estimates on how actual margin affects beliefs using the 2010 data.
- Estimate how treatment affects turnout, column 4 of 2014 data (reduced form).
- Estimate how treatment affects beliefs using 2010 data (first stage). 
- Create the TSIV estimates (TABLE 7).
- Calculate "s" based on 2014 data (Panel B of TABLE 8). The idea
of estimating "s" was suggested to us by Jesse Shapiro.
==================================================================*/
set more off

matrix input B_F = (0 \ 0 \ 0 \ 0)
matrix SE_F = B_F
matrix V_F = B_F
matrix B_TSIV = B_F
matrix SE_TSIV = B_F
matrix DelBel = B_F	

* Get estimates on changes in beliefs, DelBel.
local zX = 1
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/BothYears.dta", clear
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
	reg `kX'_pre $BeliefControls, robust
	matrix DelBel[`zX',1]  = -10*_b[margin_actual]
	local ++zX
}

* Obtain the reduced form estimates. Column 4 of 2014 RCT (Table 6).
qui do "$Main_P/2014/zz_globals_e2014.do"
use "$Temp/BothYears.dta", clear
areg vote100 t_close t_fewvoters $FullCont_V2014, absorb(strata) cluster(hhid_unique)
matrix B_R = _b[t_close]
matrix SE_R = _se[t_close]
matrix V_R = SE_R*SE_R

* Obtain the first stage estimates.
* Column 2 of Table 2. 
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/BothYears.dta", clear
areg votemarg_post t_close $demogs, robust absorb(ppstaten) 
matrix B_F[1,1]  =_b[t_close] * Theta 
matrix SE_F[1,1] =_se[t_close] * Theta 
matrix V_F[1,1]  = SE_F[1,1]*SE_F[1,1] 

* Columns 3, 6, and 9 of Table 3.
local zX = 2
foreach yX in prob_100votes prob_1000votes prob_xvotes {
	di `zX'
	areg `yX'_post t_close `yX'_pre $demogs, robust absorb(ppstaten) 
	matrix B_F[`zX',1]=_b[t_close] * Theta 
	matrix SE_F[`zX',1]=_se[t_close] * Theta 
	matrix V_F[`zX',1] = SE_F[`zX',1]*SE_F[`zX',1]
	local ++zX
}

* B_TSIV calculated by dividing reduced form by first-stage.
* SE_TSIV calculated using the Delta Method.
forvalues iX = 1/4 {
	matrix B_TSIV[`iX',1] = B_R / B_F[`iX',1]
	matrix SE_TSIV[`iX',1] = abs(1/B_F[`iX',1])*sqrt( V_R[1,1] + V_F[`iX',1] * ((B_R[1,1]/B_F[`iX',1])^2) )
}
matrix CI_L = B_TSIV - 1.96*SE_TSIV
matrix CI_H = B_TSIV + 1.96*SE_TSIV

* Output the TSIV results (THESE GO IN TABLE 7 IN MAIN TEXT)
matrix Block = ( .,.,.,. )		
matrix Regs_TSIV = ( Block 	\ Block \ Block \ Block \ Block \ Block \ Block \ Block)
matrix rowname Regs_TSIV = Predicted_vote_margin SE Pr(Marg_<100_votes) SE Pr(Marg_<1000_votes) SE <100_or_1,000_votes SE
forvalues iX=1/4{
	matrix Regs_TSIV[2*`iX'-1,`iX']=round(B_TSIV[`iX',1],.01)
	matrix Regs_TSIV[2*`iX',`iX']=round(SE_TSIV[`iX',1],.01)
}
outtable using "$ObPath/Tab-TSIV14-$spec", mat(Regs_TSIV) nobox replace center 
	
* Confidence intervals for Table 7.	Discussed in Section 3.
matrix Block = ( .,.,.,. )		
matrix CIs_TSIV = ( Block 	\ Block \ Block \ Block \ Block \ Block \ Block \ Block)
matrix rowname CIs_TSIV = Predicted_vote_margin SE Pr(Marg_<100_votes) SE Pr(Marg_<1000_votes) SE <100_or_1,000_votes SE
forvalues iX=1/4{
	matrix CIs_TSIV[2*`iX'-1,`iX']=round(CI_L[`iX',1],.01)
	matrix CIs_TSIV[2*`iX',`iX']=round(CI_H[`iX',1],.01)
}	
outtable using "$ObPath/Tab-TSIV14-CIs-$spec", mat(CIs_TSIV) nobox replace center 	
	
		
* Output the first-stage results under Theta (bottom of TABLE 7 IN MAIN TEXT).	
matrix Block = ( .,.,.,. )		
matrix Regs_F = ( Block \ Block )	
forvalues iX=1/4{
	matrix Regs_F[1,`iX']=round(B_F[`iX',1],.01)
	matrix Regs_F[2,`iX']=round(SE_F[`iX',1],.01)
}	
outtable using "$ObPath/Tab-FS-TSIV14-$spec", mat(Regs_F) nobox replace center 	
	
matrix Max_Impact = ( CI_L[1,1]*DelBel[1,1] \ CI_H[2,1]*DelBel[2,1] \ CI_H[3,1]*DelBel[3,1] \ CI_H[4,1]*DelBel[4,1] )
matrix Avg_Impact = ( B_TSIV[1,1]*DelBel[1,1] \ B_TSIV[2,1]*DelBel[2,1] \ B_TSIV[3,1]*DelBel[3,1] \ B_TSIV[4,1]*DelBel[4,1] )
matrix Min_Impact = ( CI_H[1,1]*DelBel[1,1] \ CI_L[2,1]*DelBel[2,1] \ CI_L[3,1]*DelBel[3,1] \ CI_L[4,1]*DelBel[4,1] )

matrix S_Share_Avg = Avg_Impact / (10*B_ClosenessTurnout)
foreach yX in Min Max {
	matrix S_Share_`yX' = `yX'_Impact / (10*B_ClosenessTurnout)
}
matrix S_Avg14 = S_Share_Avg

matrix S_SE = (S_Share_Avg-S_Share_Min)/1.96
scalar h_marg = 1/(S_SE[1,1]^2)
scalar h_100 = 1/(S_SE[2,1]^2)
scalar h_1k = 1/(S_SE[3,1]^2)
scalar h_1001k = 1/(S_SE[4,1]^2)
scalar Denom_3 = h_marg + h_100 + h_1k
scalar Denom_2 = h_marg + h_1001k

* Use predicted vote margin, probability of less than 100, probability less than 1,000 votes.
scalar S_Comobo3 = (h_marg*S_Share_Avg[1,1] + h_100*S_Share_Avg[2,1] + h_1k*S_Share_Avg[3,1])/ Denom_3
scalar S_Comobo3_SE = sqrt(1/Denom_3)
scalar S_Combo3_Min = round(S_Comobo3-1.96*S_Comobo3_SE,.01)
scalar S_Combo3_Max = round(S_Comobo3+1.96*S_Comobo3_SE,.01)
scalar S_Combo3_n = round((h_marg*S_Share_Avg[1,1] + h_100*S_Share_Avg[2,1] + h_1k*S_Share_Avg[3,1])/ Denom_3,.01)
matrix S_Overall = [0,0,0,0,0,S_Combo3_n,S_Combo3_Min,S_Combo3_Max]

scalar S_Comobo3_SE_Rho = sqrt((1/Denom_3) + (2/(Denom_3^2))*(Rho12*sqrt(h_marg)*sqrt(h_100)+Rho13*sqrt(h_marg)*sqrt(h_1k)+Rho23*sqrt(h_100)*sqrt(h_1k)))
scalar S_Combo3_Min_Rho = round(S_Comobo3-1.96*S_Comobo3_SE_Rho,.01)
scalar S_Combo3_Max_Rho = round(S_Comobo3+1.96*S_Comobo3_SE_Rho,.01)
matrix S_Overall_Rho = [0,0,0,0,0,S_Combo3_n,S_Combo3_Min_Rho,S_Combo3_Max_Rho]


* Use predicted vote margin and probability of less than 100/1,000 votes.
scalar S_Comobo2 = (h_marg*S_Share_Avg[1,1] + h_1001k*S_Share_Avg[4,1])/ Denom_2
scalar S_Comobo2_SE = sqrt(1/Denom_2)
scalar S_Combo2_Min = round(S_Comobo2-1.96*S_Comobo2_SE,.01)
scalar S_Combo2_Max = round(S_Comobo2+1.96*S_Comobo2_SE,.01)
scalar S_Combo2_n = round((h_marg*S_Share_Avg[1,1] + h_1001k*S_Share_Avg[4,1])/ Denom_2,.01)
matrix S_Overall2 = [0,0,0,0,0,S_Combo2_n,S_Combo2_Min,S_Combo2_Max]

forvalues iX=1/4{
	matrix DelBel[`iX',1]=round(DelBel[`iX',1],.1)
	matrix CI_L[`iX',1]=round(CI_L[`iX',1],.01)
	matrix CI_H[`iX',1]=round(CI_H[`iX',1],.01)
	matrix Min_Impact[`iX',1]=round(Min_Impact[`iX',1],.1)
	matrix Max_Impact[`iX',1]=round(Max_Impact[`iX',1],.1)
	matrix S_Share_Avg[`iX',1]=round(S_Share_Avg[`iX',1],.01)
	matrix S_Share_Min[`iX',1]=round(S_Share_Min[`iX',1],.01)
	matrix S_Share_Max[`iX',1]=round(S_Share_Max[`iX',1],.01)
}

matrix Shapiro14 = (DelBel, CI_L, CI_H, Min_Impact, Max_Impact, S_Share_Avg, S_Share_Min, S_Share_Max)
matrix Shapiro14 = (Shapiro14 \ S_Overall \ S_Overall2 \ S_Overall_Rho)
matrix rowname Shapiro14 = Predicted_vote_margin Pr(Marg_<100_votes) Pr(Marg_<1000_votes) <100_or_1,000_votes Overall Overall_2Measures Overall_Rho
matrix colname Shapiro14 = DelBel CI-Low CI-Hi Min-impact Max-impact Point-estimate-s Min-s Max-s
outtable using "$ObPath/Tab-Shapiro14-$spec", mat(Shapiro14) nobox replace center 

/*==================================================================
3. USING COMBINED DATA: DO TSIV AND ESTIMATE "s". 
This creates Panel C of TABLE 8.

What are the states in common across the two years?
2010: CA, CT, FL, GA, IL, MD, NH, NY, OH, OR, PA, TX, and WI
2014: AR, FL, GA, KS, MA, MI, and WI
There are 3 states in common: FL, GA, and WI.
==================================================================*/
set more off
matrix input B_F = (0 \ 0 \ 0 \ 0)
matrix SE_F = B_F
matrix V_F = B_F
matrix B_TSIV = B_F
matrix SE_TSIV = B_F
matrix DelBel = B_F		/* Changes in beliefs */


* Get estimates on changes in beliefs
local zX = 1
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/BothYears.dta", clear
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
	reg `kX'_pre $BeliefControls, robust
	matrix DelBel[`zX',1]  = -10*_b[margin_actual]
	local ++zX
}


set more off
use "$Temp/BothYears.dta", clear
gen vote_new = . 
replace vote_new = vote100 if year==2014
replace vote_new = vote_admin1 if year==2010
label variable vote_new "Admin vote (0/1) multiplied by 100"

* We use 10^9 for 2010 ID to ensure that the number is very different.
gen hhid_new = .
replace hhid_new  = hhid_unique if year==2014
replace hhid_new  = (10^9) + caseid if year==2010
replace vote2008 = vote_admin2008 if year==2010
foreach yX in male black hisp race_other {
	replace `yX'1=`yX' if year==2010
}

gen state_id_combo = .
replace state_id_combo = ppstaten if year==2010
replace state_id_combo = state_new if year==2014
replace state_id_combo = 59 if state=="FL"
replace state_id_combo = 58 if state=="GA"
replace state_id_combo = 35 if state=="WI"

save "$Temp/BothYears_Combo.dta", replace

* Obtain the reduced form estimates on the pooled data. 
* This is reported in last row of Panel C of Table 8.
use "$Temp/BothYears_Combo.dta", clear
reg vote_new t_close vote_admin_past male1 black1 hisp1 $AgeVars i.year i.state_id_combo, cluster(hhid_new)
matrix B_R = _b[t_close]
matrix SE_R = _se[t_close]
matrix V_R = SE_R*SE_R

* Obtain the first stage estimates.
* Column 2 of Table 2. 
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/BothYears.dta", clear
areg votemarg_post t_close $demogs, robust absorb(ppstaten) 
matrix B_F[1,1]  =_b[t_close] * Theta 
matrix SE_F[1,1] =_se[t_close] * Theta 
matrix V_F[1,1]  = SE_F[1,1]*SE_F[1,1] 

* Columns 3, 6, and 9 of Table 3.
local zX = 2
foreach yX in prob_100votes prob_1000votes prob_xvotes {
	di `zX'
	areg `yX'_post t_close `yX'_pre $demogs, robust absorb(ppstaten) 
	matrix B_F[`zX',1]=_b[t_close] * Theta 
	matrix SE_F[`zX',1]=_se[t_close] * Theta 
	matrix V_F[`zX',1] = SE_F[`zX',1]*SE_F[`zX',1]
	local ++zX
}
forvalues iX = 1/4 {
	matrix B_TSIV[`iX',1] = B_R / B_F[`iX',1]
	matrix SE_TSIV[`iX',1] = abs(1/B_F[`iX',1])*sqrt( V_R[1,1] + V_F[`iX',1] * ((B_R[1,1]/B_F[`iX',1])^2) )
}
matrix CI_L = B_TSIV - 1.96*SE_TSIV
matrix CI_H = B_TSIV + 1.96*SE_TSIV

* Output the TSIV results
matrix Block = ( .,.,.,. )		
matrix Regs_TSIV = ( Block 	\ Block \ Block \ Block \ Block \ Block \ Block \ Block)
matrix rowname Regs_TSIV = Predicted_vote_margin SE Pr(Marg_<100_votes) SE Pr(Marg_<1000_votes) SE <100_or_1,000_votes SE
forvalues iX=1/4{
	matrix Regs_TSIV[2*`iX'-1,`iX']=round(B_TSIV[`iX',1],.01)
	matrix Regs_TSIV[2*`iX',`iX']=round(SE_TSIV[`iX',1],.01)
}
outtable using "$ObPath/Tab-TSIV-Combo-$spec", mat(Regs_TSIV) nobox replace center 

matrix Max_Impact = ( CI_L[1,1]*DelBel[1,1] \ CI_H[2,1]*DelBel[2,1] \ CI_H[3,1]*DelBel[3,1] \ CI_H[4,1]*DelBel[4,1] )
matrix Avg_Impact = ( B_TSIV[1,1]*DelBel[1,1] \ B_TSIV[2,1]*DelBel[2,1] \ B_TSIV[3,1]*DelBel[3,1] \ B_TSIV[4,1]*DelBel[4,1] )
matrix Min_Impact = ( CI_H[1,1]*DelBel[1,1] \ CI_L[2,1]*DelBel[2,1] \ CI_L[3,1]*DelBel[3,1] \ CI_L[4,1]*DelBel[4,1] )

matrix S_Share_Avg = Avg_Impact / (10*B_ClosenessTurnout)
foreach yX in Min Max {
	matrix S_Share_`yX' = `yX'_Impact / (10*B_ClosenessTurnout)
}
matrix S_Avg14 = S_Share_Avg

matrix S_SE = (S_Share_Avg-S_Share_Min)/1.96
scalar h_marg = 1/(S_SE[1,1]^2)
scalar h_100 = 1/(S_SE[2,1]^2)
scalar h_1k = 1/(S_SE[3,1]^2)
scalar h_1001k = 1/(S_SE[4,1]^2)
scalar Denom_3 = h_marg + h_100 + h_1k
scalar Denom_2 = h_marg + h_1001k

* Use predicted vote margin, probability of less than 100, probability less than 1,000 votes.
scalar S_Comobo3 = (h_marg*S_Share_Avg[1,1] + h_100*S_Share_Avg[2,1] + h_1k*S_Share_Avg[3,1])/ Denom_3
scalar S_Comobo3_SE = sqrt(1/Denom_3)
scalar S_Combo3_Min = round(S_Comobo3-1.96*S_Comobo3_SE,.01)
scalar S_Combo3_Max = round(S_Comobo3+1.96*S_Comobo3_SE,.01)
scalar S_Combo3_n = round((h_marg*S_Share_Avg[1,1] + h_100*S_Share_Avg[2,1] + h_1k*S_Share_Avg[3,1])/ Denom_3,.01)
matrix S_Overall = [0,0,0,0,0,S_Combo3_n,S_Combo3_Min,S_Combo3_Max]

scalar S_Comobo3_SE_Rho = sqrt((1/Denom_3) + (2/(Denom_3^2))*(Rho12*sqrt(h_marg)*sqrt(h_100)+Rho13*sqrt(h_marg)*sqrt(h_1k)+Rho23*sqrt(h_100)*sqrt(h_1k)))
scalar S_Combo3_Min_Rho = round(S_Comobo3-1.96*S_Comobo3_SE_Rho,.01)
scalar S_Combo3_Max_Rho = round(S_Comobo3+1.96*S_Comobo3_SE_Rho,.01)
matrix S_Overall_Rho = [0,0,0,0,0,S_Combo3_n,S_Combo3_Min_Rho,S_Combo3_Max_Rho]

* Use predicted vote margin and probability of less than 100/1,000 votes.
scalar S_Comobo2 = (h_marg*S_Share_Avg[1,1] + h_1001k*S_Share_Avg[4,1])/ Denom_2
scalar S_Comobo2_SE = sqrt(1/Denom_2)
scalar S_Combo2_Min = round(S_Comobo2-1.96*S_Comobo2_SE,.01)
scalar S_Combo2_Max = round(S_Comobo2+1.96*S_Comobo2_SE,.01)
scalar S_Combo2_n = round((h_marg*S_Share_Avg[1,1] + h_1001k*S_Share_Avg[4,1])/ Denom_2,.01)
matrix S_Overall2 = [0,0,0,0,0,S_Combo2_n,S_Combo2_Min,S_Combo2_Max]


forvalues iX=1/4{
	matrix DelBel[`iX',1]=round(DelBel[`iX',1],.1)
	matrix CI_L[`iX',1]=round(CI_L[`iX',1],.01)
	matrix CI_H[`iX',1]=round(CI_H[`iX',1],.01)
	matrix Min_Impact[`iX',1]=round(Min_Impact[`iX',1],.1)
	matrix Max_Impact[`iX',1]=round(Max_Impact[`iX',1],.1)
	matrix S_Share_Avg[`iX',1]=round(S_Share_Avg[`iX',1],.01)
	matrix S_Share_Min[`iX',1]=round(S_Share_Min[`iX',1],.01)
	matrix S_Share_Max[`iX',1]=round(S_Share_Max[`iX',1],.01)
}

matrix ShapiroCombo = (DelBel, CI_L, CI_H, Min_Impact, Max_Impact, S_Share_Avg, S_Share_Min, S_Share_Max)
matrix ShapiroCombo = (ShapiroCombo \ S_Overall \ S_Overall2 \ S_Overall_Rho)
matrix rowname ShapiroCombo = Predicted_vote_margin Pr(Marg_<100_votes) Pr(Marg_<1000_votes) <100_or_1,000_votes Overall Overall_2Measures Overall_Rho
matrix colname ShapiroCombo = DelBel CI-Low CI-Hi Min-impact Max-impact Point-estimate-s Min-s Max-s
outtable using "$ObPath/Tab-ShapiroCombo-$spec", mat(ShapiroCombo) nobox replace center 



/*==================================================================
4. USING 2010 DATA: REPEAT MAIN IV RESULTS AND ESTIMATE "s".
This creates Panel A of TABLE 8.
==================================================================*/
set more off
matrix input B_F = (0 \ 0 \ 0 \ 0)
matrix B_IV = B_F
matrix SE_IV = B_F
matrix DelBel = B_F

* Get estimates on changes in beliefs
local zX = 1
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp\BothYears.dta", clear
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
	reg `kX'_pre $BeliefControls, robust
	matrix DelBel[`zX',1]  = -10*_b[margin_actual]
	local ++zX
}

* Obtain the IV estimates of how beliefs affect turnout.
set more off
qui do "$Main_P/2010/zz_globals_e2010.do"
use "$Temp/2010_RCT.dta", clear

local zX = 1
foreach kX in votemarg prob_100votes prob_1000votes prob_xvotes {
xi: ivreg2 vote_admin1 (`kX'_post=t_close) `kX'_pre $FullCont_V2010,  first robust  
	matrix B_IV[`zX',1] = _b[`kX'_post]
	matrix SE_IV[`zX',1] = _se[`kX'_post]
	local ++zX
}

matrix CI_L = B_IV - 1.96*SE_IV
matrix CI_H = B_IV + 1.96*SE_IV
matrix Max_Impact = ( CI_L[1,1]*DelBel[1,1] \ CI_H[2,1]*DelBel[2,1] \ CI_H[3,1]*DelBel[3,1] \ CI_H[4,1]*DelBel[4,1] )
matrix Avg_Impact = ( B_IV[1,1]*DelBel[1,1] \ B_IV[2,1]*DelBel[2,1] \ B_IV[3,1]*DelBel[3,1] \ B_IV[4,1]*DelBel[4,1] )
matrix Min_Impact = ( CI_H[1,1]*DelBel[1,1] \ CI_L[2,1]*DelBel[2,1] \ CI_L[3,1]*DelBel[3,1] \ CI_L[4,1]*DelBel[4,1] )

matrix S_Share_Avg = Avg_Impact / (10*B_ClosenessTurnout)
foreach yX in Min Max {
	matrix S_Share_`yX' = `yX'_Impact / (10*B_ClosenessTurnout)
}
matrix S_Avg10 = S_Share_Avg

matrix list S_Share_Avg
matrix list S_Share_Min

matrix S_SE = (S_Share_Avg-S_Share_Min)/1.96
scalar h_marg = 1/(S_SE[1,1]^2)
scalar h_100 = 1/(S_SE[2,1]^2)
scalar h_1k = 1/(S_SE[3,1]^2)
scalar h_1001k = 1/(S_SE[4,1]^2)
scalar Denom_3 = h_marg + h_100 + h_1k
scalar Denom_2 = h_marg + h_1001k

* Use predicted vote margin, probability of less than 100, probability less than 1,000 votes.
scalar S_Comobo3 = (h_marg*S_Share_Avg[1,1] + h_100*S_Share_Avg[2,1] + h_1k*S_Share_Avg[3,1])/ Denom_3
scalar S_Comobo3_SE = sqrt(1/Denom_3)
scalar S_Combo3_Min = round(S_Comobo3-1.96*S_Comobo3_SE,.01)
scalar S_Combo3_Max = round(S_Comobo3+1.96*S_Comobo3_SE,.01)
scalar S_Combo3_n = round((h_marg*S_Share_Avg[1,1] + h_100*S_Share_Avg[2,1] + h_1k*S_Share_Avg[3,1])/ Denom_3,.001)
matrix S_Overall = [0,0,0,0,0,S_Combo3_n,S_Combo3_Min,S_Combo3_Max]

scalar S_Comobo3_SE_Rho = sqrt((1/Denom_3) + (2/(Denom_3^2))*(Rho12*sqrt(h_marg)*sqrt(h_100)+Rho13*sqrt(h_marg)*sqrt(h_1k)+Rho23*sqrt(h_100)*sqrt(h_1k)))
scalar S_Combo3_Min_Rho = round(S_Comobo3-1.96*S_Comobo3_SE_Rho,.01)
scalar S_Combo3_Max_Rho = round(S_Comobo3+1.96*S_Comobo3_SE_Rho,.01)
matrix S_Overall_Rho = [0,0,0,0,0,S_Combo3_n,S_Combo3_Min_Rho,S_Combo3_Max_Rho]

* Use predicted vote margin and probability of less than 100/1,000 votes.
scalar S_Comobo2 = (h_marg*S_Share_Avg[1,1] + h_1001k*S_Share_Avg[4,1])/ Denom_2
scalar S_Comobo2_SE = sqrt(1/Denom_2)
scalar S_Combo2_Min = round(S_Comobo2-1.96*S_Comobo2_SE,.01)
scalar S_Combo2_Max = round(S_Comobo2+1.96*S_Comobo2_SE,.01)
scalar S_Combo2_n = round((h_marg*S_Share_Avg[1,1] + h_1001k*S_Share_Avg[4,1])/ Denom_2,.01)
matrix S_Overall2 = [0,0,0,0,0,S_Combo2_n,S_Combo2_Min,S_Combo2_Max]

forvalues iX=1/4{
	matrix DelBel[`iX',1]=round(DelBel[`iX',1],.1)
	matrix CI_L[`iX',1]=round(CI_L[`iX',1],.01)
	matrix CI_H[`iX',1]=round(CI_H[`iX',1],.01)
	matrix Min_Impact[`iX',1]=round(Min_Impact[`iX',1],.1)
	matrix Max_Impact[`iX',1]=round(Max_Impact[`iX',1],.1)
	matrix S_Share_Avg[`iX',1]=round(S_Share_Avg[`iX',1],.01)
	matrix S_Share_Min[`iX',1]=round(S_Share_Min[`iX',1],.01)
	matrix S_Share_Max[`iX',1]=round(S_Share_Max[`iX',1],.01)
}

matrix Shapiro10 = (DelBel, CI_L, CI_H, Min_Impact, Max_Impact, S_Share_Avg, S_Share_Min, S_Share_Max)
matrix Shapiro10 = (Shapiro10 \ S_Overall \ S_Overall2 \ S_Overall_Rho)
matrix rowname Shapiro10 = Predicted_vote_margin Pr(Marg_<100_votes) Pr(Marg_<1000_votes) <100_or_1,000_votes Overall Overall_2Measures Overall_Rho
matrix colname Shapiro10 = DelBel CI-Low CI-Hi Min-impact Max-impact Point-estimate-s Min-s Max-s
outtable using "$ObPath/Tab-Shapiro10-$spec", mat(Shapiro10) nobox replace center 

/*==================================================================
5. MISCELLANEOUS ANALYSES
===================================================================*/

/*================================================
In Section 4B, we report that the estimated 
values of s are small and not different from 0.
We also calculate the avg across the 8 filled-in rows.
================================================*/
matrix S_Avg_Combo = [S_Avg10 \ S_Avg14]
mat U = J(rowsof(S_Avg_Combo),1,1)
mat S_Avg = (U'*S_Avg_Combo)/rowsof(S_Avg_Combo)
outtable using "$ObPath/Tab-Shapiro-AvgS-$spec", mat(S_Avg) nobox replace center 


/*================================================
FN 34: COMPARE VOTING RATES BETWEEN 2010 AND 2014. 

state_id_combo = 59 corresponds to "FL".
state_id_combo = 58 corresponds to "GA".
state_id_combo = 35 corresponds to "WI".
================================================*/
use "$Temp/BothYears_Combo.dta", clear

foreach kX in 59 58 35 {
sum vote_admin1 if state_id_combo==`kX'
assert year==2010 if ~mi(vote_admin1) & state_id_combo==`kX'
sum vote2010 if state_id_combo==`kX' & age>=22
assert year==2014 if ~mi(vote2010) & state_id_combo==`kX'
}

gen both_years = (state_id_combo==59 | state_id_combo==58 | state_id_combo==35)
sum vote_admin1 if both_years==1
sum vote2010 if both_years==1 & age>=22






