/*==================================================================
 Program: Clean_Hist.do
 Purpose: Preps and cleans historical US data on gubernatorial elections.
==================================================================*/

/*===============================================================
Data were provided by James Snyder in 2010 on historical gubernatorial 
elections. The data are at the candidate level. We need to convert 
the data to being at the election level.
===============================================================*/

clear
set more off

use "$DataPath/Historical_Gub_Elections/general_GSH.dta", clear
gen counter = _n
label variable counter "Counter for sorting data"

* Restrict to elections on or after 1950
drop if year<1950

* Restrict to gubernatorial elections. This data also has house and senate.
/*
. tab office

     office |      Freq.     Percent        Cum.
------------+-----------------------------------
          G |      8,133        8.39        8.39
          H |     82,755       85.38       93.77
          S |      6,039        6.23      100.00
------------+-----------------------------------
      Total |     96,927      100.00
*/
keep if office=="G"

* Restrict to general elections. Exclude special elections,
* runoff elections, or cases where person appointed/acting Governor.
assert mi(vote_g) if type=="A"
/*
   election |
       type |      Freq.     Percent        Cum.
------------+-----------------------------------
          A |         51        1.83        1.83
          G |      2,726       97.92       99.75
          R |          2        0.07       99.82
          S |          5        0.18      100.00
------------+-----------------------------------
      Total |      2,784      100.00
*/
keep if type=="G"
assert ~mi(state) & ~mi(year)

encode state, gen(state_id)
label variable state "State"
label variable state_id "State ID"
egen elec_id=group(state_id year)
label variable elec_id "Election ID"

assert ~mi(elec_id)

/*================================================
For some elections, a candidate's name is listed 
twice. This seems to be the case when a candidate
serves as the candidate for multiple parties, as
in states that have allowed fusion voting, like NY.
We keep a candidate's entry with the highest number
of votes.
================================================*/
sort elec_id name vote_g
egen name_elec = group(elec_id name)
gsort name_elec -vote_g counter
by name_elec: gen name_elec_rank = _n
keep if name_elec_rank==1
duplicates tag elec_id name, gen(dup)
assert dup==0
drop dup name_elec name_elec_rank
 
* Total votes in the election
sort elec_id counter
by elec_id: egen totalvotes= total(vote_g)
label variable totalvotes "Total votes in an election, all candidates"

gsort elec_id -vote_g counter
by elec_id: gen elec_rank = _n
label variable elec_rank "Rank within the election, 1=winner"
assert w_g==1 if elec_rank==1
assert elec_rank==1 if w_g==1
by elec_id: gen ncands = _N
label variable ncands "Number of candidates in data for an election"

order name state year elec_id vote_g elec_rank w_g u_g

* Very few uncontested elections
/*
. tab year if u_g==1

    Year of |
   election |      Freq.     Percent        Cum.
------------+-----------------------------------
       1950 |          1        7.69        7.69
       1951 |          1        7.69       15.38
       1952 |          3       23.08       38.46
       1954 |          2       15.38       53.85
       1955 |          1        7.69       61.54
       1958 |          2       15.38       76.92
       1959 |          1        7.69       84.62
       1962 |          1        7.69       92.31
       1968 |          1        7.69      100.00
------------+-----------------------------------
      Total |         13      100.00
*/
* Drop un-contested elections
drop if u_g==1

* Check that our election rank corresponds to the winner
assert elec_rank==1 if w_g==1

* Restrict attention to top 2 candidates
keep if elec_rank==1 | elec_rank==2

* Restrict to elections with exactly 2 candidates
by elec_id: gen ncands_new = _N
keep if ncands_new==2

* Make sure all candidates win positive votes
assert ~mi(vote_g) & vote_g>0

by elec_id: egen win_vote=max(vote_g)
by elec_id: egen lose_vote=min(vote_g) 
by elec_id: egen totvotes_top2 = total(vote_g)

gen marg_votes = win_vote - lose_vote
label variable marg_votes "Margin in votes between the winner and loser"

* Obtain one person per state. We keep the winner,
* but doesn't matter, as we just want the margin.
keep if w_g==1
rename name name_winner

keep year state marg_votes

*cf _all using "$Temp/GubElecs_Hist.dta"
save "$Temp/GubElecs_Hist.dta", replace



